4.2. umbra.components.addons.projectsExplorer.projectsExplorer — Umbra 1.0.9 documentation

# 4.2. umbra.components.addons.projectsExplorer.projectsExplorer

projectsExplorer.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `ProjectsExplorer` Component Interface class and others helper objects.

Others:

## 4.2.1. Module Attributes

`umbra.components.addons.projectsExplorer.projectsExplorer.` `LOGGER`

`umbra.components.addons.projectsExplorer.projectsExplorer.` `COMPONENT_UI_FILE`

## 4.2.2. Classes

class `umbra.components.addons.projectsExplorer.projectsExplorer.` `ProjectsExplorer`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  Defines the `sibl_gui.components.addons.projectsExplorer.projectsExplorer` Component Interface class.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. name (unicode) – Component name. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `dockArea`

    Property for self.__dockArea attribute.

    Returns: | self.__dockArea.
    Return type: | int

  `engine`

    Property for self.__engine attribute.

    Returns: | self.__engine.
    Return type: | QObject

  `settings`

    Property for self.__settings attribute.

    Returns: | self.__settings.
    Return type: | QSettings

  `settingsSection`

    Property for self.__settingsSection attribute.

    Returns: | self.__settingsSection.
    Return type: | unicode

  `scriptEditor`

    Property for self.__scriptEditor attribute.

    Returns: | self.__scriptEditor.
    Return type: | QWidget

  `model`

    Property for self.__model attribute.

    Returns: | self.__model.
    Return type: | ProjectsProxyModel

  `view`

    Property for self.__view attribute.

    Returns: | self.__view.
    Return type: | QWidget

  `delegate`

    Property for self.__delegate attribute.

    Returns: | self.__delegate.
    Return type: | QItemDelegate

  `style`

    Property for self.__style attribute.

    Returns: | self.__style.
    Return type: | Style

  `activate`(engine)

    Activates the Component.

    Parameters: | engine (QObject) – Engine to attach the Component to.
    Returns: | Method success.
    Return type: | bool

  `deactivate`()

    Deactivates the Component.

    Returns: | Method success.
    Return type: | bool

  `initializeUi`()

    Initializes the Component ui.

    Returns: | Method success.
    Return type: | bool

  `uninitializeUi`()

    Uninitializes the Component ui.

    Returns: | Method success.
    Return type: | bool

  `addWidget`()

    Adds the Component Widget to the engine.

    Returns: | Method success.
    Return type: | bool

  `removeWidget`()

    Removes the Component Widget from the engine.

    Returns: | Method success.
    Return type: | bool

  `getSelectedNodes`()

    Returns the View selected nodes.

    Returns: | View selected nodes.
    Return type: | dict

  `removeProject`(node)

    Removes the project associated with given node.

    Parameters: | node (ProjectNode or DirectoryNode or FileNode) – Node.
    Returns: | Method success.
    Return type: | bool

  `addNewFile`(node)

    Adds a new file next to given Node associated path.

    Parameters: | node (ProjectNode or DirectoryNode or FileNode) – Node.
    Returns: | Method success.
    Return type: | bool

  `addNewDirectory`(node)

    Adds a new directory next to given Node associated path.

    Parameters: | node (ProjectNode or DirectoryNode or FileNode) – Node.
    Returns: | Method success.
    Return type: | bool

  `rename`(node)

    Renames given Node associated path.

    Parameters: | node (ProjectNode or DirectoryNode or FileNode) – Node.
    Returns: | Method success.
    Return type: | bool

  `delete`(node)

    Deletes given Node associated path.

    Parameters: | node (ProjectNode or DirectoryNode or FileNode) – Node.
    Returns: | Method success.
    Return type: | bool